@@ -12,7 +12,7 @@ import logging
 import sys
 from pathlib import Path
 
-from docgen import finder, loader, converter
+from docgen import finder, loader, patcher, converter
 from docgen.utils import timed, debug_traceback
 
 
@@ -63,6 +63,15 @@ def create_parser():
         choices=converter.CONVERTERS,
         default="json-html",
     )
+    parser.add_argument(
+        "--no-patches",
+        action="store_true",
+        help="Don't apply automatic patches to generated output")
+    parser.add_argument(
+        "--no-curdir",
+        action="store_true",
+        help="Don't parse resources from current directory",
+    )
     parser.add_argument(
         "-v", "--verbose", help="be more talkative", action="store_true"
     )
@@ -86,7 +95,7 @@ def run(raw_args=None):
                 matches = finder.builtins()
                 include = "*"
             else:
-                matches = finder.find_all()
+                matches = finder.find_all(curdir=(not args.no_curdir))
                 include = args.pattern
 
         with timed("Filter"):
@@ -102,6 +111,11 @@ def run(raw_args=None):
                 except ImportError:
                     debug_traceback()
 
+        if not args.no_patches:
+            with timed("Patch"):
+                for lib in libraries:
+                    patcher.apply_all(lib)
+
         args.output.mkdir(parents=True, exist_ok=True)
         with timed("Convert"):
             for lib in libraries:
