@@ -22,7 +22,7 @@ def convert(libdoc, fmt, dirname):
 
     path = Path(dirname) / filename
     converter().convert(libdoc, path)
-    logging.debug("Created file: %s", path)
+    logging.info("Created file: %s", path)
 
 
 class ConverterMeta(abc.ABCMeta):
