@@ -4,7 +4,6 @@ import time
 import traceback
 from contextlib import contextmanager
 from pathlib import Path
-from robot.utils import normalize, unic
 
 
 @contextmanager
@@ -43,11 +42,3 @@ def path_to_name(path):
         return "{}.{}".format(namespace, path.stem)
     else:
         return path.stem
-
-
-def fix_scope(libdoc):
-    """Convert documentation scope to RPA terminology."""
-    normalized = normalize(unic(libdoc.scope), ignore="_")
-    libdoc.scope = {"testcase": "Task", "testsuite": "Suite", "global": "Global"}.get(
-        normalized, libdoc.scope
-    )
